@@ -1,10 +1,11 @@
-# Copyright (C) 2009-2013  Roman Zimbelmann <hut@lavabit.com>
-# This software is distributed under the terms of the GNU GPL version 3.
+# This file is part of ranger, the console file manager.
+# License: GNU GPL version 3, see the file "AUTHORS" for details.
 
 """The main function responsible to initialize the FM object and stuff."""
 
 import os.path
 import sys
+import tempfile
 
 def main():
     """initialize objects and run the filemanager"""
@@ -110,6 +111,12 @@ def main():
             from ranger.ext import curses_interrupt_handler
             curses_interrupt_handler.install_interrupt_handler()
 
+        # Create cache directory
+        if fm.settings.preview_images and fm.settings.use_preview_script:
+            from ranger import CACHEDIR
+            if not os.path.exists(CACHEDIR):
+                os.makedirs(CACHEDIR)
+
         # Run the file manager
         fm.initialize()
         ranger.api.hook_init(fm)
@@ -127,8 +134,8 @@ def main():
             import pstats
             profile = None
             ranger.__fm = fm
-            cProfile.run('ranger.__fm.loop()', '/tmp/ranger_profile')
-            profile = pstats.Stats('/tmp/ranger_profile', stream=sys.stderr)
+            cProfile.run('ranger.__fm.loop()', tempfile.gettempdir()+'/ranger_profile')
+            profile = pstats.Stats(tempfile.gettempdir()+'/ranger_profile', stream=sys.stderr)
         else:
             fm.loop()
     except Exception:
@@ -159,7 +166,7 @@ def main():
             print(crash_traceback)
             print("ranger crashed.  " \
                 "Please report this traceback at:")
-            print("http://savannah.nongnu.org/bugs/?group=ranger&func=additem")
+            print("https://github.com/hut/ranger/issues")
             return 1
         return 0
 
@@ -187,7 +194,7 @@ def parse_arguments():
             help="change the configuration directory. (%default)")
     parser.add_option('--copy-config', type='string', metavar='which',
             help="copy the default configs to the local config directory. "
-            "Possible values: all, rc, rifle, commands, scope")
+            "Possible values: all, rc, rifle, commands, commands_full, scope")
     parser.add_option('--fail-unless-cd', action='store_true',
             help=SUPPRESS_HELP)  # COMPAT
     parser.add_option('-m', '--mode', type='int', default=0, metavar='n',
@@ -248,11 +255,14 @@ def load_settings(fm, clean):
 
         # Load custom commands
         if os.path.exists(fm.confpath('commands.py')):
+            old_bytecode_setting = sys.dont_write_bytecode
+            sys.dont_write_bytecode = True
             try:
                 import commands
                 fm.commands.load_commands_from_module(commands)
             except ImportError:
                 pass
+            sys.dont_write_bytecode = old_bytecode_setting
 
         allow_access_to_confdir(ranger.arg.confdir, False)
 
