@@ -1,5 +1,5 @@
-# Copyright (C) 2009-2013  Roman Zimbelmann <hut@lavabit.com>
-# This software is distributed under the terms of the GNU GPL version 3.
+# This file is part of ranger, the console file manager.
+# License: GNU GPL version 3, see the file "AUTHORS" for details.
 
 """Shared objects contain singletons for shared use."""
 
@@ -16,10 +16,3 @@ class SettingsAware(object):
     @staticmethod
     def _setup(settings):
         SettingsAware.settings = settings
-
-class EnvironmentAware(object):  # COMPAT
-    """DO NOT USE.  This is for backward compatibility only."""
-    @lazy_property
-    def env(self):
-        from ranger.core.environment import Environment
-        return Environment(".")
